Performs a Goodness-of-Fit procedure along the lines of
Hunter, Goodreau, and Handcock (2008). Statistics are simulated
from an fitted mlergm object, which can then be plotted and visualized.
An example is given in the documentation of mlergm.
# S3 method for mlergm
gof(object, ..., options = set_options(), seed = NULL,
gof_form = NULL)Additional arguments to be passed if necessary.
See set_options for details.
A seed to be provided to ensure reproducibility of results.
A formula object of the form ~ term1 + term2 + ... for statistics to compute for the GOF procedure.
gof.mlergm returns an object of class gof_mlergm which is a list containing:
The GOF statistic values of the observed network.
The GOF statistic values simulated from the the estimated mlergm objeect provided.
Hunter, D. R., Goodreau, S. M., and Handcock, M. S. (2008). Goodness of fit of social network models. Journal of the American Statistical Association, 103(481), 248-258.